import { Reporter } from 'qcloud-iotexplorer-appdev-sdk';
import { DeviceFilterFunction } from 'qcloud-iotexplorer-bluetooth-adapter';
import { LLSyncDeviceAdapterBase, LLSyncDeviceAdapterOptions } from 'qcloud-iotexplorer-bluetooth-adapter-llsync';
export declare const LLSyncComboConfig: {
    waitGetDeviceInfoTime: number;
    waitSetWiFiModeTime: number;
    waitSetWiFiInfoTime: number;
    waitSetWiFiConnectTime: number;
    waitSetWiFiTokenTime: number;
    waitDevLogInfoTime: number;
};
export declare class BleComboLLSyncDeviceAdapterBase extends LLSyncDeviceAdapterBase {
    static options: LLSyncDeviceAdapterOptions;
    static serviceId16: string;
    static serviceId: string;
    static deviceFilter: DeviceFilterFunction;
    static injectOptions(options: LLSyncDeviceAdapterOptions): void;
    bleVersion: any;
    reporter: Reporter;
    notifyMessage({ type, data }?: any): Promise<any>;
    connectDevice(params: any): Promise<void>;
    afterConnectDevice(): Promise<string>;
    getDeviceInfo(): Promise<{
        version: number;
        mtu: number;
        needSetMtu: boolean;
        deviceName: string;
    }>;
    /**
     * @description WiFi模式设置
     * @returns boolean 表示设置WiFi模式成功或者失败
     */
    setWiFiMode(mode?: string): Promise<boolean>;
    /**
     *
     * @param params0 {Object} 配网的WiFi信息
     * @param parmas0.ssid {String} WiFi的ssid
     * @param params0.password {String} WiFi的密码
     * @returns {boolean} 传输WiFi结果
     */
    setWiFiInfo({ ssid, password, }: {
        ssid: string;
        password: string;
    }): Promise<boolean>;
    /**
     * @description 下发WiFi连接请求，并获取连接状态
     * @returns {boolean} WiFi连接状态
     */
    sendConnectWiFiAndGetWiFiConnectState(): Promise<{
        connected: boolean;
        ssid: string;
    }>;
    sendToken({ token, }: {
        token: string;
    }): Promise<boolean>;
    getModuleLog(): Promise<{
        logStr: string;
    }>;
}
export declare const BleComboLLSyncDeviceAdapter: (new (...args: any[]) => {
    bluetoothAdapter: import("qcloud-iotexplorer-bluetooth-adapter").BlueToothAdapter;
    extendInfo: any;
    _h5Websocket: any;
    _name: string;
    _deviceId: string;
    _deviceName: string;
    _deviceConnected: boolean;
    _productId: string;
    _deviceRegistered: boolean;
    _services: any[];
    characteristicsMap: {};
    _actions: Pick<import("qcloud-iotexplorer-bluetooth-adapter").BlueToothActions, "registerDevice" | "bindDevice" | "reportDeviceData">;
    _bluetoothApi: any;
    communicationMode: import("qcloud-iotexplorer-bluetooth-adapter").CommunicationMode;
    _getNotifyId({ serviceId }?: {
        serviceId?: string;
    }): any;
    readonly _writeId: any;
    readonly _notifyId: any;
    readonly _readId: any;
    readonly _indicateId: any;
    readonly deviceId: string;
    readonly productId: string;
    deviceName: string;
    readonly isConnected: boolean;
    readonly originName: string;
    readonly explorerDeviceId: string;
    readonly serviceId: any;
    readonly deviceInfo: {
        productId: string;
        deviceName: string;
        deviceId: string;
        explorerDeviceId: string;
        name: string;
    };
    init(): Promise<void>;
    handleBLEMessage(hexStrArr: string[], { serviceId, characteristicId }: {
        serviceId: string;
        characteristicId: string;
    }): import("qcloud-iotexplorer-bluetooth-adapter").BLEMessageResponse;
    registerDevice(): Promise<void>;
    bindDevice({ familyId, roomId, }?: {
        familyId?: string;
        roomId?: string;
    }): Promise<string>;
    onBleConnectionStateChange({ connected }: {
        connected: any;
    }): void;
    onBLECharacteristicValueChange({ serviceId, characteristicId, value, }: {
        serviceId: any;
        characteristicId: any;
        value: any;
    }): Promise<void>;
    disconnectDevice(): void;
    connectDevice({ autoNotify, }?: {
        autoNotify?: boolean;
    }): Promise<void>;
    write(data: any, { writeId, serviceId, }?: {
        writeId?: string;
        serviceId?: string;
    }): Promise<void>;
    _write(value: any, { writeId, serviceId, }?: {
        writeId?: string;
        serviceId?: string;
    }): Promise<void>;
    getBLEDeviceServices(): Promise<any>;
    setCharacteristicsIds(serviceId: any, characteristics: any): void;
    getBLEDeviceCharacteristics({ serviceId, }?: {
        serviceId?: string;
    }): Promise<any>;
    notifyBLECharacteristicValueChange({ characteristicId, serviceId, state, }?: {
        characteristicId?: string;
        serviceId?: string;
        state?: boolean;
    }): Promise<void>;
    readBLECharacteristicValue({ serviceId, characteristicId, }?: {
        serviceId?: string;
        characteristicId?: string;
    }): Promise<void>;
    setBLEMTU(params: {
        deviceId?: string;
        mtu: number;
    }): any;
    getBLEDeviceRSSI(): any;
    destroy(): void;
    advertFilter(advert: any): any;
    onScanAdvert(params: any): void;
    _cleanupMap: {};
    _normalizeError(error: any): any;
    cleanup(action?: string): void;
    addCleanupTask(action: any, cleanupFn: any): void;
    on: (type: string, listener: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    once: (type: any, listener: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    off: (type: any, listener?: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    emit: (type: any, ...argus: any[]) => Promise<any>;
}) & typeof BleComboLLSyncDeviceAdapterBase;
export declare const BleComboLLSyncDeviceAdapter4H5: (new (...props: any[]) => {
    write(data: any, writeId: any): Promise<void>;
    bluetoothAdapter: import("qcloud-iotexplorer-bluetooth-adapter").BlueToothAdapter;
    extendInfo: any;
    _h5Websocket: any;
    _name: string;
    _deviceId: string;
    _deviceName: string;
    _deviceConnected: boolean;
    _productId: string;
    _deviceRegistered: boolean;
    _services: any[];
    characteristicsMap: {};
    _actions: Pick<import("qcloud-iotexplorer-bluetooth-adapter").BlueToothActions, "registerDevice" | "bindDevice" | "reportDeviceData">;
    _bluetoothApi: any;
    communicationMode: import("qcloud-iotexplorer-bluetooth-adapter").CommunicationMode;
    _getNotifyId({ serviceId }?: {
        serviceId?: string;
    }): any;
    readonly _writeId: any;
    readonly _notifyId: any;
    readonly _readId: any;
    readonly _indicateId: any;
    readonly deviceId: string;
    readonly productId: string;
    deviceName: string;
    readonly isConnected: boolean;
    readonly originName: string;
    readonly explorerDeviceId: string;
    readonly serviceId: any;
    readonly deviceInfo: {
        productId: string;
        deviceName: string;
        deviceId: string;
        explorerDeviceId: string;
        name: string;
    };
    init(): Promise<void>;
    handleBLEMessage(hexStrArr: string[], { serviceId, characteristicId }: {
        serviceId: string;
        characteristicId: string;
    }): import("qcloud-iotexplorer-bluetooth-adapter").BLEMessageResponse;
    registerDevice(): Promise<void>;
    bindDevice({ familyId, roomId, }?: {
        familyId?: string;
        roomId?: string;
    }): Promise<string>;
    onBleConnectionStateChange({ connected }: {
        connected: any;
    }): void;
    onBLECharacteristicValueChange({ serviceId, characteristicId, value, }: {
        serviceId: any;
        characteristicId: any;
        value: any;
    }): Promise<void>;
    disconnectDevice(): void;
    connectDevice({ autoNotify, }?: {
        autoNotify?: boolean;
    }): Promise<void>;
    _write(value: any, { writeId, serviceId, }?: {
        writeId?: string;
        serviceId?: string;
    }): Promise<void>;
    getBLEDeviceServices(): Promise<any>;
    setCharacteristicsIds(serviceId: any, characteristics: any): void;
    getBLEDeviceCharacteristics({ serviceId, }?: {
        serviceId?: string;
    }): Promise<any>;
    notifyBLECharacteristicValueChange({ characteristicId, serviceId, state, }?: {
        characteristicId?: string;
        serviceId?: string;
        state?: boolean;
    }): Promise<void>;
    readBLECharacteristicValue({ serviceId, characteristicId, }?: {
        serviceId?: string;
        characteristicId?: string;
    }): Promise<void>;
    setBLEMTU(params: {
        deviceId?: string;
        mtu: number;
    }): any;
    getBLEDeviceRSSI(): any;
    destroy(): void;
    advertFilter(advert: any): any;
    onScanAdvert(params: any): void;
    _cleanupMap: {};
    _normalizeError(error: any): any;
    cleanup(action?: string): void;
    addCleanupTask(action: any, cleanupFn: any): void;
    on: (type: string, listener: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    once: (type: any, listener: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    off: (type: any, listener?: import("event-emitter-for-miniprogram").listenerCallback) => import("event-emitter-for-miniprogram").default;
    emit: (type: any, ...argus: any[]) => Promise<any>;
}) & typeof BleComboLLSyncDeviceAdapterBase;
